==> hp300_1.0.tar: hp300/examples/concepts/basic2.ex <==
#! /usr/lib/veetest/veetest -d /usr/lib/veetest -r
(revision "A.00.00")
(date "Wed 10/Apr/1991")
(component 0 "Context"
 (name "HP BASIC Function Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "HPBasic"
   (name "Init HP BASIC/UX")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (component progname "/usr/lib/veetest/examples/concepts/function.bas")
   )
   (views
    (icon
    )
    (detail
     (origin 6 543)
     (extent 228 34)
    )
    (active detail)
   )
  )
  (component 1 "Start"
   (name "Start")
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 86 451)
     (extent 69 39)
    )
    (detail
     (origin 586 400)
     (extent 129 20)
    )
    (active icon)
   )
  )
  (component 2 "NamedPipe"
   (name "To/From HP BASIC/UX")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (attr iopath file read "/tmp/from_rmb"
     (readTerm "\n")
     (fs " ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (attr iopath file append "/tmp/to_rmb"
     (readTerm "\n")
     (fs ", ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (procedure
      WRITE TEXT a EOL
      READ TEXT x REAL COUNT:100
    )
   )
   (views
    (icon
     (iconImage basic.icon)
    )
    (detail
     (origin 541 612)
     (extent 299 116)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 3 "ForRange"
   (name "For Range")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component from 1)
    (component thru 5)
    (component step 2)
   )
   (views
    (icon
     (iconImage loop.icon)
    )
    (detail
     (origin 36 627)
     (extent 168 86)
    )
    (active detail)
   )
  )
  (component 4 "Formula"
   (name "Formula")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "ramp(100, -a,a)")
   )
   (views
    (icon
     (origin 321 568)
     (extent 78 64)
     (iconImage formula.icon)
    )
    (detail
     (origin 232 644)
     (extent 196 52)
    )
    (active detail)
   )
  )
  (component 5 "Note"
   (name "Overview of HP BASIC/UX function example")
   (interface
   )
   (implementation
    (component text 29 5
     Pupose: Show how to use an HP BASIC/UX
     program to process and return data.
     
     Explanation:
     The "Init HP BASIC/UX" object inititates an
     HP BASIC/UX process which loads and runs
     the specified file.  If the HP BASIC/UX process
     is already running the program, this object
     does nothing.
     
     The ramp function generates a vector of
     100 numbers evenly spaced.  The entire vector
     is sent to the HP BASIC/UX program via the
     named pipe.  The program is known to return
     exactly 100 numbers.  Trying to read too many
     or too few numbers from the pipe would cause
     synchronization problems.
     
     The processing done by the BASIC program is
     presumably the result of an existing program.
     
     Edit the simple.bas program to see what is
     needed on the HP BASIC/UX end.
     
     Notice that even after the model in this 
     example has finished executing that the 
     HP BASIC/UX process is still running.  It must
     be stopped manually.
     
    )
   )
   (views
    (icon
     (extent 370 0)
    )
    (detail
     (origin 12 118)
     (extent 457 325)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 6 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 522 119)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 7 "YPlot"
   (name "XY Trace")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "line")
     (lock constraints)
    )
    (input 2
     (type data)
     (name "parabola")
     (lock constraints)
     (optional yes)
    )
    (input 3
     (type control)
     (name "Next Curve")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
    (component tracePin 1)
    (component tracePin 2)
    (component graphMode rectangular)
   )
   (views
    (icon
     (iconImage display.icon)
    )
    (detail
     (origin 530 249)
     (extent 460 282)
     (displayMode annotGraph)
     (graphType cartesian)
     (gridType grid)
     (scale 0
      (name "Y")
      (domainName "X")
      (color 0x909090)
      (show 1)
      (range -5 25 3 linear)
     )
     (domain 0 100 3 linear)
     (trace 0 onScale 0
      (name "line")
      (color 0xffdd00)
      (lineType 1)
      (pointType 0)
     )
     (trace 1 onScale 0
      (name "parabola")
      (color 0xccff)
      (lineType 1)
      (pointType 0)
     )
    )
    (active detail)
   )
  )
  (configuration
   (connect D1:0 D0:0)
   (connect D4:1 D2:1)
   (connect D0:0 D3:0)
   (connect D3:1 D4:1)
   (connect D4:1 D7:1)
   (connect D2:1 D7:2)
   (connect D4:1 D7:3)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 979 658)
   (configuration
    (connect D1:0 D0:0
     (Point 120 492)
     (Point 120 510)
    )
    (connect D4:1 D2:1
     (Point 430 670)
     (Point 498 670)
    )
    (connect D0:0 D3:0
     (Point 120 579)
     (Point 120 594)
    )
    (connect D3:1 D4:1
     (Point 206 670)
     (Point 229 670)
    )
    (connect D4:1 D7:1
     (Point 430 670)
     (Point 480 670)
     (Point 480 480)
     (Point 500 480)
     (Point 500 300)
     (Point 527 300)
    )
    (connect D2:1 D7:2
     (Point 872 670)
     (Point 890 670)
     (Point 890 560)
     (Point 510 560)
     (Point 510 390)
     (Point 527 390)
    )
    (connect D4:1 D7:3
     (Point 430 670)
     (Point 480 670)
     (Point 480 480)
     (Point 527 480)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)

==> hp300_1.2.tar: hp300/examples/concepts/basic2.ex <==
#! /usr/lib/veetest/veetest -r
(revision "A.00.00")
(date "Wed 10/Apr/1991")
(component 0 "Context"
 (name "HP BASIC Function Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "HPBasic"
   (name "Init HP BASIC/UX")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (component progname "/usr/lib/veetest/examples/concepts/function.bas")
   )
   (views
    (icon
    )
    (detail
     (origin 6 543)
     (extent 228 34)
    )
    (active detail)
   )
  )
  (component 1 "Start"
   (name "Start")
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 86 451)
     (extent 69 39)
    )
    (detail
     (origin 586 400)
     (extent 129 20)
    )
    (active icon)
   )
  )
  (component 2 "NamedPipe"
   (name "To/From HP BASIC/UX")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (attr iopath file read "/tmp/from_rmb"
     (readTerm "\n")
     (fs " ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (attr iopath file append "/tmp/to_rmb"
     (readTerm "\n")
     (fs ", ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (procedure
      WRITE TEXT a EOL
      READ TEXT x REAL COUNT:100
    )
   )
   (views
    (icon
     (iconImage basic.icon)
    )
    (detail
     (origin 541 612)
     (extent 299 116)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 3 "ForRange"
   (name "For Range")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component from 1)
    (component thru 5)
    (component step 2)
   )
   (views
    (icon
     (iconImage loop.icon)
    )
    (detail
     (origin 36 627)
     (extent 168 86)
    )
    (active detail)
   )
  )
  (component 4 "Formula"
   (name "Formula")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "ramp(100, -a,a)")
   )
   (views
    (icon
     (origin 321 568)
     (extent 78 64)
     (iconImage formula.icon)
    )
    (detail
     (origin 232 644)
     (extent 196 52)
    )
    (active detail)
   )
  )
  (component 5 "Note"
   (name "Overview of HP BASIC/UX function example")
   (interface
   )
   (implementation
    (component text 29 5
     Purpose: Show how to use an HP BASIC/UX
     program to process and return data.
     
     Explanation:
     The "Init HP BASIC/UX" object initiates an
     HP BASIC/UX process which loads and runs
     the specified file.  If the HP BASIC/UX process
     is already running the program, this object
     does nothing.
     
     The ramp function generates a vector of
     100 numbers evenly spaced.  The entire vector
     is sent to the HP BASIC/UX program via the
     named pipe.  The program is known to return
     exactly 100 numbers.  Trying to read too many
     or too few numbers from the pipe would cause
     synchronization problems.
     
     The processing done by the BASIC program is
     presumably the result of an existing program.
     
     Edit the simple.bas program to see what is
     needed on the HP BASIC/UX end.
     
     Notice that even after the model in this 
     example has finished executing that the 
     HP BASIC/UX process is still running.  It must
     be stopped manually.
     
    )
   )
   (views
    (icon
     (extent 370 0)
    )
    (detail
     (origin 12 118)
     (extent 457 325)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 6 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 522 119)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 7 "YPlot"
   (name "XY Trace")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "line")
     (lock constraints)
    )
    (input 2
     (type data)
     (name "parabola")
     (lock constraints)
     (optional yes)
    )
    (input 3
     (type control)
     (name "Next Curve")
     (lock name constraints)
     (optional yes)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
    (component tracePin 1)
    (component tracePin 2)
    (component graphMode rectangular)
   )
   (views
    (icon
     (iconImage display.icon)
    )
    (detail
     (origin 530 249)
     (extent 460 282)
     (displayMode annotGraph)
     (graphType cartesian)
     (gridType grid)
     (scale 0
      (name "Y")
      (domainName "X")
      (color 0x909090)
      (show 1)
      (range -5 25 3 linear)
     )
     (domain 0 100 3 linear)
     (trace 0 onScale 0
      (name "line")
      (color 0xffdd00)
      (lineType 1)
      (pointType 0)
     )
     (trace 1 onScale 0
      (name "parabola")
      (color 0xccff)
      (lineType 1)
      (pointType 0)
     )
    )
    (active detail)
   )
  )
  (configuration
   (connect D1:0 D0:0)
   (connect D4:1 D2:1)
   (connect D0:0 D3:0)
   (connect D3:1 D4:1)
   (connect D4:1 D7:1)
   (connect D2:1 D7:2)
   (connect D4:1 D7:3)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 979 658)
   (configuration
    (connect D1:0 D0:0
     (Point 120 492)
     (Point 120 510)
    )
    (connect D4:1 D2:1
     (Point 430 670)
     (Point 498 670)
    )
    (connect D0:0 D3:0
     (Point 120 579)
     (Point 120 594)
    )
    (connect D3:1 D4:1
     (Point 206 670)
     (Point 229 670)
    )
    (connect D4:1 D7:1
     (Point 430 670)
     (Point 480 670)
     (Point 480 480)
     (Point 500 480)
     (Point 500 300)
     (Point 527 300)
    )
    (connect D2:1 D7:2
     (Point 872 670)
     (Point 890 670)
     (Point 890 560)
     (Point 510 560)
     (Point 510 390)
     (Point 527 390)
    )
    (connect D4:1 D7:3
     (Point 430 670)
     (Point 480 670)
     (Point 480 480)
     (Point 527 480)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
